<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Upravljanik uporabnikov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administracija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Dodaj novega uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Dodaj uporabniški račun</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Vnesite geslo za novega uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>geslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Ponovno vnesi geslo za novega uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>potrdi geslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Uporabniško ime novega uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Uporabniško ime za prijavo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Vnesite uporabniško ime novega uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>uporabniško ime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Geslo novega uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Potrdi geslo uporabnika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Geslo uporabnika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation>Uporabniku omogočite skrbniške pravice za sistem (sudo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Izbriši uporabniški računa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Izberi uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Izberi uporabnika, ki ga želite izbrisati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Uporabnik za izbris</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Izbriši tudi domačo direktorij uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Izbriši domačo direktorij uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Premimenuje uporabniški račun</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Izberite uporabnika za spreminjanje:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Novo uporabniško ime:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Spremeni geslo uproabnika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>novo geslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Potrdi novo geslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>potrdi novo geslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Novo geslo uporabnika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Popravi uporabnikovo konfiguracijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Spremeni uporabniški račun</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Izberi uporabnika za popravilo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Uporabnik, katerega se spreminja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Obnovi privzete nastavitve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Obnovi konfiguracijo brskalnika na privzete nastavitve za MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla (Iceweasel ali Firefox) konfiguracije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Obnovi članstvo v skupinah na privzete nastavitve za MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Članstvo v skupinah</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Spremeni nastavitve za samodejno prijavo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Samodejna prijava</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Zahtevaj geslo za prijavo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Kopiranje/sinhronizacija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Kopiranje med namizij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Izberi namizje s katerega naj se kopira</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Zgolj kopiranje datotek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Zgolj kopiranje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Izberi namizje na katerega naj se kopira</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Kopiraj na:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Kopiraj iz:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Izberi za kopiranje in potem izbriši razlike </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Sinhronizacija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Izberite za kopiranje/sinhronizianje virov v skupni rabi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Skupna mapa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Izberi za kopiranje ali sinhornizacijo celotne domače mape</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Celotna domača mapa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Izberi za kopiranje ali sinhronizacijo konfiguracije brskalnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Iceweasel ali Firefox) konfiguracije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Izberi za kopiranje ali sinhronizacijo dokumentov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Mapa z dokumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Kaj naj se kopira ali sinhronizira:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Napredek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Status sprememb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Napredek sprememb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Dodaj/odstrani skupine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Dodaj skupino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation>Vnesite ime nove skupine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>groupname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation>Ustvari skupino z GID &gt; 1000</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation>Ustvari skupino na nivoju uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Vnesite ime nove skupine &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Ime skupine:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Izbriši skupino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Izberite skupino za izbris&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation>Izberite skupino za brisanje:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation>*Preverite izbor pred izvedbo, saj lahko odstranitev napačne skupine pokvari sistem.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Članstvo v skupini</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Člani skupine pripadajo (spreminjajte skupine z izbiranjem ustreznih polj):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation>*Preverite izbiro pred potrditvijo. Določanje napačnih članstev v skupinah lahko pokavri vaš sistem. Uporabite zavihek Popravi za obnovo originalnega članstva, če ste storili napako.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Izberite uporabnika za spremembo&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Zavrzi vse spremembe in izstopi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Uveljavi vse spremembe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="154"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="180"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="672"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <location filename="../mainwindow.cpp" line="723"/>
        <location filename="../mainwindow.cpp" line="871"/>
        <location filename="../mainwindow.cpp" line="936"/>
        <location filename="../mainwindow.cpp" line="942"/>
        <location filename="../mainwindow.cpp" line="947"/>
        <location filename="../mainwindow.cpp" line="950"/>
        <location filename="../mainwindow.cpp" line="952"/>
        <source>none</source>
        <translation>brez</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <location filename="../mainwindow.cpp" line="877"/>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>browse...</source>
        <translation>brskanje...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Uporabniška konfiguracija bo popravljena. Prosimo, zaprite vse aplikacije. Po zaključku se odjavite ali ponovno zaženite sistem. Ste prepričani, da želite pričeti s popravilom?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>User group membership was restored.</source>
        <translation>Članstvo upoabnika v skupini je bilo obnovljeno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation>Mozilla nastavitve so bile ponastavljene.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Autologin options</source>
        <translation>Nastavitve za samodejno prijavo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="240"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Samodejna prijava je izključena za račun &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Samodejna prijava je vključena za račun &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Določiti morate cilj za &apos;kopiranje v&apos;. Ne morete kopirati na namizje na katerega ste prijavljeni.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Pred kopiranjem zaprite vse ostale aplikacije. Preverite, da je cilj kopiranja dovolj velik za datoteke, ki jih kopirate. Kopiranje med namizji lahko prepiše ali izbiriše datoteke na viljnem namizju. Ste prepričani, da želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Synchronizing desktop...</source>
        <translation>Sinhronizacija namizij ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Copying desktop...</source>
        <translation>Kopiranje namizij ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Uporabniško imeti dolžino vsaj dveh znakov. Izberite daljše ime za nadaljevanje.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Uporabniško ime ne more vsebovati posebnih znakov ali presledkov.
Prosimo, izberite drugo ime pred nadaljevanjem.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Oprostite, to ime se že uporablja. Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Gesli se ne ujemata. Poskusite znova.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Gesli morata imeti dolžino vsaj dveh znakov. Vnesite daljše geslo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>The user was added ok.</source>
        <translation>Uporabnik je bil uspešno dodan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Failed to add the user.</source>
        <translation>Uporabnik ni bil uspešno dodan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Password successfully changed.</source>
        <translation>Geslo je bilo uspešno spremenjeno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Failed to change password.</source>
        <translation>Neuspel poskus spremembe gesla.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Te akcije ni mogoče razaveljaviti. Ali ste prepričani, da želite izbrisati uporabnika %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>The user has been deleted.</source>
        <translation>Uporabnik je bil izbrisan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Failed to delete the user.</source>
        <translation>Uporabnika ni bilo mogoče izbrisati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Ime skupine mora imeti dolžino vsaj dveh znakov. Izberite daljše ime za nadaljevanje.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Ime skupine mora vsebovati le majhne znake in
mora biti brez posebnih znakov ali presledkov.
Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Oprostite, to ime skupine  je že v rabi. Prosimo, izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>The system group was added ok.</source>
        <translation>Skupina je bila uspešno dodana.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Failed to add the system group.</source>
        <translation>Neuspešno dodajanje skupine.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Tega ni mogoče razveljaviti. Ali ste prepričani, da želite izbrisati skupino %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation>Tega dejanja ni mogoče razveljaviti. Ali ste prepričani,d a želite izbrisati skupine: %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Failed to delete the group.</source>
        <translation>Skupine ni bilo mogoče izbrisati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Group: %1</source>
        <translation>Skupina: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>The group has been deleted.</source>
        <translation>Skupina je bila izbrisana.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>The groups have been deleted.</source>
        <translation>Skupine so bile izbrisane.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>The changes have been applied.</source>
        <translation>Spremembe so bile uspešno izvedene.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Failed to apply group changes</source>
        <translation>Potrjevanje sprememb skupin ni bilo uspešno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>The selected user name is currently in use.</source>
        <translation>Izbrano uporabniško ime se že uporablja.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Za preimenovanje tega uporabnika se odjavite in ponovno prijavite z drugim uporabniškim računom.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Uporabniško ime mora vsebovati le majhne znake in
mora biti brez posebnih znakov ali presledkov.
Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Oprostite, to ime je na vašem sistemu že v rabi. Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Neuspešno preimenovanje uporabnika. Prepričajte se, da uporabnik ni prijavljen. Morda bo potreben ponoven zagon.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>The user was renamed.</source>
        <translation>Uporabnik je bil preimenovan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sinhronizacija namizja... uspela!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Copying desktop...ok</source>
        <translation>Kopiranje namizja... uspelo!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sinhronizacija namizja... neuspešno!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Copying desktop...failed</source>
        <translation>Kopiranje namizia... neuspešno!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Confirmation</source>
        <translation>Potrditev</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Proces ni bil zaključen. Želite vseeno končati program?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="844"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Preprosto konfiguriranje uporabnikov za MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="878"/>
        <source>Select folder to copy to</source>
        <translation>Izberite ciljno mapo za kopiranje</translation>
    </message>
</context>
<context>
    <name>PassEdit</name>
    <message>
        <location filename="../passedit.cpp" line="144"/>
        <source>Negligible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="144"/>
        <source>Very weak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="144"/>
        <source>Weak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="145"/>
        <source>Moderate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="145"/>
        <source>Strong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="145"/>
        <source>Very strong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="147"/>
        <source>Password strength: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="180"/>
        <source>Hide the password</source>
        <translation>Skrij geslo</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="180"/>
        <source>Show the password</source>
        <translation>Prikaži geslo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Prijavljeni ste kot korenski (root) uporabnik. Odjavite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
    </message>
</context>
</TS>
